@@ -1,3 +1,5 @@
+import math
+
 from sh3ll import IS
 
 
@@ -20,4 +22,14 @@ def multiply(ctx):
     print("M:", int(ctx.parameters[0]) * int(ctx.parameters[1]))
 
 
-app.run()
\ No newline at end of file
+@app.command(name="prog", help="progress bar tester", progress=(2000, 3000))
+def prog(ctx):
+    nums = [x * 5 for x in range(2000, 3000)]
+    results = []
+
+    for i, x in enumerate(nums):
+        results.append(math.factorial(x))
+        ctx.progress_bar.progress(1)
+
+
+app.run()
